import os
import logging
import time
import types

try:
    import unittest.mock as mock
except ImportError:
    import mock
import json
import os
from unittest import TestCase

from tweeply import Tweeply, Stream, TweeplyClient, TweeplyMessage

CONFIG = {'DB': {'URL': 'postgresql://tweeply:tweeply@postgres-dev/tweeply'}}

class TestServer(TestCase):

    def test_tweeply(self):
        """
        The main task starts, spawns the appropriate workers, and finishes cleanly.
        """
        tweeply = Tweeply(name="Tweeply", config=CONFIG)
        tweeply.setDaemon(False)
        workers = [mock.Mock()]
        tweeply.workers = workers
        tweeply.start()
        tweeply.stop()
        tweeply.join()
        assert workers[0].start.called
        assert workers[0].stop.called


class TestClient(TestCase):
    @mock.patch.object(TweeplyClient, "receive_generic")
    @mock.patch.object(TweeplyClient, "send_generic")
    def test_client(self, send, receive):
        response = TweeplyMessage()
        response.payload = "restpayload"
        response.collection = "testing"
        response.multipart = False
        receive.return_value = response
        c = TweeplyClient(config=CONFIG)
        res = c.rest.get_some_method()
        assert res == "restpayload"
        response.payload = "stream"
        response.multipart = True
        gen = c.stream.sample(tweeply_timeout=0, tweeply_polling=0)
        assert isinstance(gen, types.GeneratorType)
        response.multipart = True
        response.code = 100
        response.payload = "stream0"
        assert gen.next() == "stream0"
        response.payload = "stream1"
        assert gen.next() == "stream1"
        response.code = 203
        self.assertRaises(StopIteration, gen.next)



import os
import logging
import time
from copy import copy

try:
    import unittest.mock as mock
except ImportError:
    import mock
import json
import os
from unittest import TestCase

from tweeply import TweeplyMessage, ClientMessage

class TestMessages(TestCase):
    
    def test_message(self):
        """
        Generic Messages should be of the form:
          { "code": 200,
            "thread": None,
            "multipart": False,
            "id": -1,
            "payload": None,
            "collection": None,
            "stimestamp": None,
            "rtimestamp": None}
        """
        m = TweeplyMessage()
        reference_message = {
                             "code": 200,
                             "thread": None,
                             "multipart": False,
                             "id": -1,
                             "payload": {},
                             "collection": None,
                             "stimestamp": None,
                             "rtimestamp": None}
        assert m.to_dict() == reference_message 
        
        intext = m.to_json()
        recovered = TweeplyMessage.from_raw([intext])
        assert recovered.to_dict() == reference_message

    def test_serialise_message(self):
        pass


    def test_client(self):
        """
        Client Messages should be of the form:
          { 
            "code": 200,
            "thread": None,
            "multipart": False,
            "id": -1,
            "payload": {
                "fname": [],
                "args": [],
                "kwargs": {}
            },
            "collection": None,
            "stimestamp": None,
            "rtimestamp": None}
        """
        m = ClientMessage()
        reference_client = {
                             "code": 200,
                             "thread": None,
                             "multipart": False,
                             "id": -1,
                             "payload": {
                                 "fname": [],
                                 "kwargs": {},
                                 "args": []},
                             "collection": None,
                             "stimestamp": None,
                             "rtimestamp": None }
        assert m.to_dict() == reference_client
        m.fname = ["foo"]
        m.args = [0,1,2]
        m.kwargs["fourth"] = 3
        reference_client["payload"] = {"fname": ["foo"], "args": [0,1,2], "kwargs": {"fourth": 3}}
        assert m.to_dict() == reference_client

        intext = m.to_json()
        recovered = TweeplyMessage.from_raw([intext])
        assert recovered.to_dict() == reference_client

    def test_copy_server(self):
        """ When copied, a message should return a message """
        m = TweeplyMessage()
        cm = m.copy()
        assert isinstance(cm, TweeplyMessage)
        assert cm == m
        cm2 = copy(m)
        assert isinstance(cm2, TweeplyMessage)
        assert cm2 == m


    def test_copy_client(self):
        """ When copied, a message should return a message """
        m = ClientMessage()
        cm = m.copy()
        assert isinstance(cm, ClientMessage)
        assert cm == m
        cm2 = copy(m)
        assert isinstance(cm2, ClientMessage)
        assert cm2 == m

    def test_reply(self):
        m = ClientMessage()
        r = m.buildReply("test")
        assert r.payload == "test"



import os
import logging
import time
import types

try:
    import unittest.mock as mock
except ImportError:
    import mock
import json
import os
from unittest import TestCase

from tweeply import utils
from tweeply import defaults 

class TestMisc(TestCase):

    def test_config(self):
        """
        The main task starts, spawns the appropriate workers, and finishes cleanly.
        """
        config = {}
        config = utils.generic_update_config(config)
        assert config == {}
        config = utils.update_config(config, cfgfiles=[])
        assert config == defaults.DEFAULTS
        config = utils.update_config(config,
                                     defaults=defaults.DEFAULTS,
                                     cfgfiles=["/dev/null",])
        assert config == defaults.DEFAULTS
        config = {}
        TEST_DEFAULTS = {"TWEEPLY": {"nested": True}}
        TEST_FILE = "{}/config-test.json".format(os.path.dirname(__file__))
        logging.debug("TEST_FILE %s", TEST_FILE)
        config = utils.update_config(config,
                                     defaults=TEST_DEFAULTS,
                                     cfgfiles=[TEST_FILE,])
        assert config == {"TWEEPLY": "NOTHING", "HTTP": "NOTHING", "and": "test" }



import pip
from setuptools import setup
from pip.req import parse_requirements

# parse_requirements() returns generator of pip.req.InstallRequirement objects
# pip 6 introduces the *required* session argument
try:
    install_reqs = parse_requirements("requirements.txt", session=pip.download.PipSession())
    test_reqs = parse_requirements("test-requirements.txt", session=pip.download.PipSession())
except AttributeError:
    install_reqs = parse_requirements("requirements.txt")
    test_reqs = parse_requirements("test-requirements.txt")

# reqs is a list of requirement
# e.g. ['django==1.5.1', 'mezzanine==1.4.6']
install_reqs = [str(ir.req) for ir in install_reqs]
test_reqs = [str(ir.req) for ir in test_reqs]


setup(
    name="tweeply",
    description='''
    Simplifying how researchers access Twitter's API.
    It includes a CLI and a library.
    ''',
    author='J. Fernando Sanchez',
    author_email='balkian@gmail.com',
    url="http://balkian.com",
    version="0.6",
    py_modules=["tweeply"],
    install_requires=install_reqs,
    tests_require=test_reqs,
    include_package_data=True,
    entry_points="""
        [console_scripts]
        tweeply=tweeply.cli:manager
    """
)
